@@ -80,7 +80,7 @@ class TunnellingRequest(KNXIPBody):
             + self.cemi.to_knx()
         )
 
-    def __str__(self) -> str:
+    def __repr__(self) -> str:
         """Return object as readable string."""
         return (
             "<TunnellingRequest "
